@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -170,7 +170,8 @@ int main(int argc, char **argv)
     printf("\nip_bitDepth = %d\ntest_case = %d", ip_bitDepth, test_case);
 
     rppHandle_t handle;
-    rppCreate(&handle);
+    RppBackend backend = RppBackend::RPP_HOST_BACKEND;
+    rppCreate(&handle, 2, 0, nullptr, backend);
 
     clock_t start, end;
     double start_omp, end_omp;
@@ -961,6 +962,8 @@ int main(int argc, char **argv)
         break;
     }
 
+    rppDestroy(handle, backend);
+
     if (missingFuncFlag == 1)
     {
         cout << "\nThis functionality sub-type of " << test_case_name << " doesn't yet exist in RPP\n";
