@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -31,7 +31,7 @@ int main(int argc, char **argv)
     if (argc < MIN_ARG_COUNT)
     {
         cout << "\nImproper Usage! Needs all arguments!\n";
-        cout << "\nUsage: ./Tensor_host_audio <src folder> <case number = 0:7> <test type 0/1> <numRuns> <batchSize> <dst folder>\n";
+        cout << "\nUsage: ./Tensor_audio_host <src folder> <case number = 0:7> <test type 0/1> <numRuns> <batchSize> <dst folder>\n";
         return -1;
     }
 
@@ -105,7 +105,7 @@ int main(int argc, char **argv)
     Rpp32u offsetInBytes = 0;
     set_audio_descriptor_dims_and_strides(srcDescPtr, batchSize, maxSrcHeight, maxSrcWidth, maxSrcChannels, offsetInBytes);
     int maxDstChannels = maxSrcChannels;
-    if(testCase == 3)
+    if(testCase == DOWN_MIXING)
     {
         srcDescPtr->numDims = 3;
         maxDstChannels = 1;
@@ -115,7 +115,7 @@ int main(int argc, char **argv)
     // create generic descriptor in case of slice
     RpptGenericDesc descriptor3D;
     RpptGenericDescPtr descriptorPtr3D = &descriptor3D;
-    if(testCase == 5)
+    if(testCase == SLICE)
     {
         descriptorPtr3D->numDims = 2;
         descriptorPtr3D->offsetInBytes = 0;
@@ -126,14 +126,27 @@ int main(int argc, char **argv)
     }
 
     // set buffer sizes for src/dst
-    iBufferSize = (Rpp64u)srcDescPtr->h * (Rpp64u)srcDescPtr->w * (Rpp64u)srcDescPtr->c * (Rpp64u)srcDescPtr->n;
-    oBufferSize = (Rpp64u)dstDescPtr->h * (Rpp64u)dstDescPtr->w * (Rpp64u)dstDescPtr->c * (Rpp64u)dstDescPtr->n;
+    if(testCase == MEL_FILTER_BANK)
+    {
+        iBufferSize = (Rpp64u)MEL_FILTER_BANK_MAX_HEIGHT * (Rpp64u)srcDescPtr->w * (Rpp64u)srcDescPtr->c * (Rpp64u)srcDescPtr->n;
+        oBufferSize = (Rpp64u)MEL_FILTER_BANK_MAX_HEIGHT * (Rpp64u)dstDescPtr->w * (Rpp64u)dstDescPtr->c * (Rpp64u)dstDescPtr->n;
+    }
+    else
+    {
+        iBufferSize = (Rpp64u)srcDescPtr->h * (Rpp64u)srcDescPtr->w * (Rpp64u)srcDescPtr->c * (Rpp64u)srcDescPtr->n;
+        oBufferSize = (Rpp64u)dstDescPtr->h * (Rpp64u)dstDescPtr->w * (Rpp64u)dstDescPtr->c * (Rpp64u)dstDescPtr->n;
+    }
 
     // compute maximum possible buffer size of resample
-    unsigned long long resampleMaxBufferSize = dstDescPtr->n * dstDescPtr->strides.nStride * 1.15;
-    if (testCase == 6)
+    Rpp64u resampleMaxBufferSize = dstDescPtr->n * dstDescPtr->strides.nStride * 1.15;
+    if (testCase == RESAMPLE)
         oBufferSize = resampleMaxBufferSize;
 
+    // compute maximum possible buffer size of spectrogram
+    Rpp64u spectrogramMaxBufferSize = 257 * 3754 * dstDescPtr->n;
+    if (testCase == SPECTROGRAM)
+        oBufferSize = spectrogramMaxBufferSize;
+
     // allocate host buffers for input & output
     Rpp32f *inputf32 = (Rpp32f *)calloc(iBufferSize, sizeof(Rpp32f));
     Rpp32f *outputf32 = (Rpp32f *)calloc(oBufferSize, sizeof(Rpp32f));
@@ -152,11 +165,14 @@ int main(int argc, char **argv)
     // RpptResamplingWindow instance used for resample augmentation
     RpptResamplingWindow window;
 
-    // run case-wise RPP API and measure time
+    // Set the number of threads to be used by OpenMP pragma for RPP batch processing on host.
+    // If numThreads value passed is 0, number of OpenMP threads used by RPP will be set to batch size
+    Rpp32u numThreads = 0;
     rppHandle_t handle;
-    rppCreateWithBatchSize(&handle, srcDescPtr->n, 3);
+    RppBackend backend = RppBackend::RPP_HOST_BACKEND;
+    rppCreate(&handle, batchSize, numThreads, nullptr, backend);
 
-    int noOfIterations = (int)audioNames.size() / batchSize;
+    int noOfIterations = static_cast<int>(audioNames.size()) / batchSize;
     double maxWallTime = 0, minWallTime = 500, avgWallTime = 0;
     string testCaseName;
     cout << "\nRunning " << func << " " << numRuns << " times (each time with a batch size of " << batchSize << " audio files) and computing mean statistics...";
@@ -170,7 +186,7 @@ int main(int argc, char **argv)
             double wallTime;
             switch (testCase)
             {
-                case 0:
+                case NON_SILENT_REGION_DETECTION:
                 {
                     testCaseName = "non_silent_region_detection";
                     Rpp32f cutOffDB = -60.0;
@@ -183,7 +199,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 1:
+                case TO_DECIBELS:
                 {
                     testCaseName = "to_decibels";
                     Rpp32f cutOffDB = std::log(1e-20);
@@ -201,7 +217,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 2:
+                case PRE_EMPHASIS_FILTER:
                 {
                     testCaseName = "pre_emphasis_filter";
                     Rpp32f coeff[batchSize];
@@ -218,7 +234,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 3:
+                case DOWN_MIXING:
                 {
                     testCaseName = "down_mixing";
                     bool normalizeWeights = false;
@@ -237,7 +253,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 4:
+                case SPECTROGRAM:
                 {
                     testCaseName = "spectrogram";
                     bool centerWindows = true;
@@ -255,40 +271,23 @@ int main(int argc, char **argv)
 
                     maxDstWidth = 0;
                     maxDstHeight = 0;
-                    if(dstDescPtr->layout == RpptLayout::NFT)
-                    {
-                        for(int i = 0; i < noOfAudioFiles; i++)
-                        {
-                            dstDims[i].height = nfft / 2 + 1;
-                            dstDims[i].width = ((srcLengthTensor[i] - windowOffset) / windowStep) + 1;
-                            maxDstHeight = std::max(maxDstHeight, (int)dstDims[i].height);
-                            maxDstWidth = std::max(maxDstWidth, (int)dstDims[i].width);
-                        }
-                    }
-                    else
-                    {
-                        for(int i = 0; i < noOfAudioFiles; i++)
-                        {
-                            dstDims[i].height = ((srcLengthTensor[i] - windowOffset) / windowStep) + 1;
-                            dstDims[i].width = nfft / 2 + 1;
-                            maxDstHeight = std::max(maxDstHeight, (int)dstDims[i].height);
-                            maxDstWidth = std::max(maxDstWidth, (int)dstDims[i].width);
-                        }
-                    }
+                    init_spectrogram(srcDescPtr, dstDescPtr, dstDims, srcLengthTensor, windowLength,
+                                     windowStep, windowOffset, nfft, maxDstHeight, maxDstWidth);
 
-                    set_audio_descriptor_dims_and_strides_nostriding(dstDescPtr, batchSize, maxDstHeight, maxDstWidth, maxDstChannels, offsetInBytes);
-                    dstDescPtr->numDims = 3;
-
-                    // Set buffer sizes for src/dst
-                    unsigned long long spectrogramBufferSize = (unsigned long long)dstDescPtr->h * (unsigned long long)dstDescPtr->w * (unsigned long long)dstDescPtr->c * (unsigned long long)dstDescPtr->n;
-                    outputf32 = (Rpp32f *)realloc(outputf32, spectrogramBufferSize * sizeof(Rpp32f));
+                    // check if the output buffer size is greater than predefined spectrogramMaxBufferSize
+                    if (dstDescPtr->n * dstDescPtr->strides.nStride > spectrogramMaxBufferSize)
+                    {
+                        std::cout << "\nError! Requested spectrogram output size is greater than predefined max size for spectrogram in test suite."
+                                     "\nPlease modify spectrogramMaxBufferSize value in test suite for running spectrogram kernel" << std::endl;
+                        exit(0);
+                    }
 
                     startWallTime = omp_get_wtime();
                     rppt_spectrogram_host(inputf32, srcDescPtr, outputf32, dstDescPtr, srcLengthTensor, centerWindows, reflectPadding, windowFn, nfft, power, windowLength, windowStep, handle);
 
                     break;
                 }
-                case 5:
+                case SLICE:
                 {
                     testCaseName = "slice";
                     Rpp32u nDim = 1; // testing for 1D slice
@@ -314,7 +313,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 6:
+                case RESAMPLE:
                 {
                     testCaseName = "resample";
                     Rpp32f inRateTensor[batchSize];
@@ -354,7 +353,7 @@ int main(int argc, char **argv)
 
                     break;
                 }
-                case 7:
+                case MEL_FILTER_BANK:
                 {
                     testCaseName = "mel_filter_bank";
 
@@ -364,41 +363,10 @@ int main(int argc, char **argv)
                     RpptMelScaleFormula melFormula = RpptMelScaleFormula::SLANEY;
                     Rpp32s numFilter = 80;
                     bool normalize = true;
-                    Rpp32s srcDimsTensor[] = {257, 225, 257, 211, 257, 214}; // (height, width) for each tensor in a batch for given QA inputs.
-                    // Accepts outputs from FT layout of Spectrogram for QA
-                    srcDescPtr->layout = dstDescPtr->layout = RpptLayout::NFT;
+                    // (height, width) for each tensor in a batch for given QA inputs.
+                    Rpp32s srcDimsTensor[] = {257, 225, 257, 211, 257, 214};
 
-                    maxDstHeight = 0;
-                    maxDstWidth = 0;
-                    maxSrcHeight = 0;
-                    maxSrcWidth = 0;
-                    for(int i = 0, j = 0; i < batchSize; i++, j += 2)
-                    {
-                        maxSrcHeight = std::max(maxSrcHeight, (int)srcDimsTensor[j]);
-                        maxSrcWidth = std::max(maxSrcWidth, (int)srcDimsTensor[j + 1]);
-                        dstDims[i].height = numFilter;
-                        dstDims[i].width = srcDimsTensor[j + 1];
-                        maxDstHeight = std::max(maxDstHeight, (int)dstDims[i].height);
-                        maxDstWidth = std::max(maxDstWidth, (int)dstDims[i].width);
-                    }
-                    srcDescPtr->h = maxSrcHeight;
-                    srcDescPtr->w = maxSrcWidth;
-                    dstDescPtr->h = maxDstHeight;
-                    dstDescPtr->w = maxDstWidth;
-                    
-                    set_audio_descriptor_dims_and_strides_nostriding(srcDescPtr, batchSize, maxSrcHeight, maxSrcWidth, maxSrcChannels, offsetInBytes);
-                    set_audio_descriptor_dims_and_strides_nostriding(dstDescPtr, batchSize, maxDstHeight, maxDstWidth, maxDstChannels, offsetInBytes);
-                    srcDescPtr->numDims = 3;
-                    dstDescPtr->numDims = 3;
-
-                    // Set buffer sizes for src/dst
-                    unsigned long long spectrogramBufferSize = (unsigned long long)srcDescPtr->h * (unsigned long long)srcDescPtr->w * (unsigned long long)srcDescPtr->c * (unsigned long long)srcDescPtr->n;
-                    unsigned long long melFilterBufferSize = (unsigned long long)dstDescPtr->h * (unsigned long long)dstDescPtr->w * (unsigned long long)dstDescPtr->c * (unsigned long long)dstDescPtr->n;
-                    inputf32 = (Rpp32f *)realloc(inputf32, spectrogramBufferSize * sizeof(Rpp32f));
-                    outputf32 = (Rpp32f *)realloc(outputf32, melFilterBufferSize * sizeof(Rpp32f));
-
-                    // Read source data
-                    read_from_bin_file(inputf32, srcDescPtr, srcDimsTensor, "spectrogram", scriptPath);
+                    init_mel_filter_bank(&inputf32, &outputf32, srcDescPtr, dstDescPtr, dstDims, offsetInBytes, numFilter, batchSize, srcDimsTensor, scriptPath, testType);
 
                     startWallTime = omp_get_wtime();
                     rppt_mel_filter_bank_host(inputf32, srcDescPtr, outputf32, dstDescPtr, srcDimsTensor, maxFreq, minFreq, melFormula, numFilter, sampleRate, normalize, handle);
@@ -428,7 +396,7 @@ int main(int argc, char **argv)
         // QA mode - verify outputs with golden outputs. Below code doesn’t run for performance tests
         if (testType == 0)
         {
-            if (testCase == 0)
+            if (testCase == NON_SILENT_REGION_DETECTION)
                 verify_non_silent_region_detection(detectedIndex, detectionLength, testCaseName, batchSize, audioNames, dst);
             else
                 verify_output(outputf32, dstDescPtr, dstDims, testCaseName, dst, scriptPath, "HOST");
@@ -448,7 +416,7 @@ int main(int argc, char **argv)
             }
         }
     }
-    rppDestroyHost(handle);
+    rppDestroy(handle, backend);
 
     // performance test mode
     if (testType == 1)
@@ -470,6 +438,6 @@ int main(int argc, char **argv)
     free(dstDims);
     free(inputf32);
     free(outputf32);
-        
+
     return 0;
 }
