@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -50,6 +50,8 @@ int main(int argc, char * argv[])
     inputBitDepth = atoi(argv[10]);
     string scriptPath = argv[11];
 
+    bool nonQACase = (testCase == 6);
+
     if ((layoutType < 0) || (layoutType > 2))
     {
         fprintf(stdout, "\nUsage: %s <header file> <data file> <layoutType = 0 - PKD3/ 1 - PLN3/ 2 - PLN1>\n", argv[0]);
@@ -148,7 +150,8 @@ int main(int argc, char * argv[])
     // If numThreads value passed is 0, number of OpenMP threads used by RPP will be set to batch size
     Rpp32u numThreads = 0;
     rppHandle_t handle;
-    rppCreateWithBatchSize(&handle, noOfFiles, numThreads);
+    RppBackend backend = RppBackend::RPP_HOST_BACKEND;
+    rppCreate(&handle, noOfFiles, numThreads, nullptr, backend);
 
     // Run case-wise RPP API and measure time
     int missingFuncFlag = 0;
@@ -222,7 +225,7 @@ int main(int argc, char * argv[])
             double startWallTime, endWallTime;
             switch (testCase)
             {
-                case 0:
+                case FUSED_MULTIPLY_ADD_SCALAR:
                 {
                     testCaseName = "fused_multiply_add_scalar";
                     Rpp32f *mulTensor = reinterpret_cast<Rpp32f *>(pinnedMemArgs);
@@ -242,7 +245,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 1:
+                case SLICE:
                 {
                     testCaseName = "slice";
                     if(anchorTensor == NULL)
@@ -265,7 +268,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 2:
+                case ADD_SCALAR:
                 {
                     testCaseName = "add_scalar";
                     Rpp32f addTensor[batchSize];
@@ -281,7 +284,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 3:
+                case SUBTRACT_SCALAR:
                 {
                     testCaseName = "subtract_scalar";
                     Rpp32f subtractTensor[batchSize];
@@ -297,7 +300,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 4:
+                case FLIP_VOXEL:
                 {
                     testCaseName = "flip_voxel";
                     Rpp32u horizontalTensor[batchSize];
@@ -321,7 +324,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 5:
+                case MULTIPLY_SCALAR:
                 {
                     testCaseName = "multiply_scalar";
                     Rpp32f mulTensor[batchSize];
@@ -337,7 +340,7 @@ int main(int argc, char * argv[])
 
                     break;
                 }
-                case 6:
+                case GAUSSIAN_NOISE_VOXEL:
                 {
                     testCaseName = "gaussian_noise_voxel";
                     Rpp32f meanTensor[batchSize];
@@ -412,7 +415,7 @@ int main(int argc, char * argv[])
 
             // if test case is slice and qaFlag is set, update the ROI with shapeTensor values
             // for output display and comparison purposes
-            if(testCase == 1)
+            if(testCase == SLICE)
             {
                 // update the roi for comparision with the shapeTensor values
                 if (descriptorPtr3D->layout == RpptLayout::NCDHW)
@@ -446,7 +449,7 @@ int main(int argc, char * argv[])
             /*Compare the output of the function with golden outputs only if
             1.QA Flag is set
             2.input bit depth 2 (F32)*/
-            if(qaFlag && inputBitDepth == 2)
+            if(qaFlag && inputBitDepth == 2  && !(nonQACase))
                 compare_output(outputF32, oBufferSize, testCaseName, layoutType, descriptorPtr3D, (RpptRoiXyzwhd *)roiGenericSrcPtr, dstPath, scriptPath);
             else
             {
@@ -523,7 +526,7 @@ int main(int argc, char * argv[])
         cout << fixed << "\nmax,min,avg wall times in ms/batch = " << maxWallTime << "," << minWallTime << "," << avgWallTime;
     }
 
-    rppDestroyHost(handle);
+    rppDestroy(handle, backend);
 
     // Free memory
     free(niftiDataArray);
